import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;

/**
 *
 * The legend box can arrange titles in multiple columns and multiple rows. This application
 * demonstrates how to change legend column layout and set column and row gaps.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com 
 */
public class Main extends JFrame implements ItemListener,AdjustmentListener {

    JCheckBox autoColGap;

    JScrollBar rowGap,colGap;

    JComboBox columns;

    Graph graph;

    public Main() {


	// Creates top and bottom panels and components to adjust legend column  and column/row gaps.
	createTopAndBottomPanel();
	
	// Creates the chart context and line series.
	createGraphAndSeries();

	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });

	setTitle("The JetChart Library - Legend Demo");
	setSize(650,500);
	setVisible(true);

    }

   

    private void createTopAndBottomPanel() {

        String[] items={"1 column","2 columns","3 columns","4 columns","5 columns",
                  "6 columns","7 columns","8 columns","9 columns","10 columns"};
	columns=new JComboBox(items);

	columns.setSelectedIndex(2);

	columns.addItemListener(this);
    
	colGap=new JScrollBar(JScrollBar.HORIZONTAL,70,1,1,201);
        colGap.setPreferredSize(new Dimension(100,colGap.getPreferredSize().height));
	colGap.addAdjustmentListener(this);

	rowGap=new JScrollBar(JScrollBar.HORIZONTAL,10,1,1,30);
        rowGap.setPreferredSize(new Dimension(100,rowGap.getPreferredSize().height));
	rowGap.addAdjustmentListener(this);

	autoColGap=new JCheckBox("Automatic column gap");
	autoColGap.addItemListener(this);

	
	JPanel topPanel=new JPanel(new FlowLayout(FlowLayout.LEFT));

	topPanel.add(new JLabel("Nr of columns:"));
	topPanel.add(columns);

	topPanel.add(new JLabel("Column gap:"));
	topPanel.add(colGap);
	
	topPanel.add(new JLabel("Row gap:"));
	topPanel.add(rowGap);

        Container ct=getContentPane();

	ct.add("North",topPanel);

	JPanel bottomPanel=new JPanel(new FlowLayout(FlowLayout.LEFT));
	bottomPanel.add(autoColGap);
	
	ct.add("South",bottomPanel);


    }

    private void createGraphAndSeries() {

	graph=new Graph();
	
	// Configures the legend to display 3 columns only.
	graph.getLegend().setColumnLayout(3);
	/**
	 * Sets  the  legend  column  gap  to 70 pixels. The  column gap
	 * is the distance  in  pixels between a title icon and the next
	 * one on the right. There is a 5 pixels margin around each icon
	 * that is not included in the column gap.
	 */
	graph.getLegend().setColumnGap(70);

	/**
	 * Sets the legend row gap to 10 pixels. There is a 5 pixels margin
	 * around each icon that is not included in the row gap.
	 */
	graph.getLegend().setRowGap(10);

	graph.setTitle(new String[]{"The JetChart Library","Legend  Demo"});

	graph.setLabels(new String[]{"l1","l2","l3","l4","l5","l6","l7","l8","l9","l10"});

	Color[] colors={Color.red,Color.blue,Color.green,Color.yellow,Color.magenta,Color.pink,
			Color.cyan,Color.green.darker(),Color.lightGray,Color.orange};

	String title=null;
	for (int counter=0;counter<10;counter++) {
	    if (counter<9)
		title="Line Series "+(counter+1);
	    else
		title="Last Line\nSeries";
	    
	    LineSerie ls=new LineSerie(new double[]{3543,3000,2890,2991,3000,2500,2300,1900,2200,1800},
				       title);
	    ls.setColor(colors[counter]);
	
	    graph.addSerie(ls);

	}

	graph.getGraphSet(0).getGrid().setEnabled(true);
	graph.getGraphSet(0).getGridCrossedLines().setEnabled(true);
	graph.setVDepth(5);
	graph.set3DEnabled(true);
	
        Container ct=getContentPane();

	ct.add("Center",graph);

    }

     public void itemStateChanged(ItemEvent evt) {

	if (evt.getSource()==autoColGap) {
	    
	    // Toggles automatic calculation of column gap.
	    colGap.setEnabled(!autoColGap.isSelected());

	    if (autoColGap.isSelected()) 

		/**
		 * To enable automatic calculation of column gap, just pass the 'zero' 
		 * value to the setColumnGap method.
		 */
		graph.getLegend().setColumnGap(0);
	    else 
		/**
		 * To manually set the column gap, pass a value different from 'zero'
		 * to the setColumnGap method.
		 */
		graph.getLegend().setColumnGap(colGap.getValue());
	}
	else if (evt.getSource()==columns)

	    // Sets the number of legend columns.
	    graph.getLegend().setColumnLayout(columns.getSelectedIndex()+1);
	
	// Any of these legend changes requires a chart refresh.
	graph.refresh();
	
    }

    public void adjustmentValueChanged(AdjustmentEvent evt) {
	
	if (evt.getSource()==colGap)
	    graph.getLegend().setColumnGap(colGap.getValue());
	else 
	    graph.getLegend().setRowGap(rowGap.getValue());
	
	graph.refresh();
    }

  

    public static void main(String[] args) {
	new Main();
    }
}


