import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;

/**
 *
 * This demo displays a chart with two line series.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com 
 */
public class Main extends JFrame implements ItemListener,AdjustmentListener  {
    Graph graph;
    LineSerie ls1,ls2;

    JCheckBox is3D,isHorizontal;

    JScrollBar depth;

    public Main() {
	
	// A title for the frame
	setTitle("The JetChart Library - Line Chart Demo");
	
	// Values for the series
	double[] values1={250,200,250,280,300,240,230,160,180,210};
	double[] values2={220,-150,60,100,130,160,140,110,100,80};
	
	// Creates two line series
        ls1=new LineSerie(values1,"Line Series 1");
        ls2=new LineSerie(values2,"Line Series 2");
		
	// Sets line series properties
	setLineSeriesProperties();
	
	// Creates graphic context, passing labels
	graph=new Graph();
	// Sets chart properties
	setChartProperties();

	// Adds the line series to the graphic context
	graph.addSerie(ls1);
	graph.addSerie(ls2);

       	String[] labels={"label1","label2","label3","label4","label5",
			 "label6","label7","label8","label9","label10"};

	graph.setLabels(labels);

        Container ct=getContentPane();

	ct.add("Center",graph);

	// Creates a top panel to layout components
	createTopPanel();

	// Adds window adapter
	addWindowListener(new WindowAdapter() {
	    public void windowClosing(WindowEvent evt) {
		System.exit(0);
	    }
	});

	setSize(600,450);

	// Centers frame on the screen
	Dimension d=getToolkit().getScreenSize();
	setLocation((d.width-getSize().width)/2,(d.height-getSize().height)/2);

	setVisible(true);

    }

    // Event handler for 3D state and chart orientation
    public void itemStateChanged(ItemEvent evt) {
	if (evt.getSource()==is3D) {
	    graph.set3DEnabled(is3D.isSelected());
	    depth.setEnabled(is3D.isSelected());
	}
	else if (evt.getSource()==isHorizontal) {
	    boolean hor=isHorizontal.isSelected();

	    graph.setHorizontalGraphEnabled(hor);
	    if (!hor) {
		graph.getLeftTitle().setText("Values Title");
		graph.getBottomTitle().setText("Labels Title");
	    }
	    else {
		graph.getLeftTitle().setText("Labels Title");
		graph.getBottomTitle().setText("Values Title");
	    }
	}
	graph.repaint();
    }

    // Event handler for chart depth adjustment
    public void adjustmentValueChanged(AdjustmentEvent evt) {
	if (evt.getSource()==depth) {
	    graph.setVDepth(depth.getValue());
	    graph.setHDepth(depth.getValue());
	    graph.repaint();
	}
    }
	    
    // Creates top panel
    private void createTopPanel( ) {

	// Creates top panel with a border around
	JPanel topPanel=new JPanel();

	topPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
	
	//  Checkbox for 3D property.
	is3D=new JCheckBox("3D");
	is3D.setFont(new Font("Arial",Font.PLAIN,10));
	is3D.addItemListener(this);
	
	// Checkbox for chart orientation property
	isHorizontal=new JCheckBox("Horizontal");
	isHorizontal.setFont(new Font("Arial",Font.PLAIN,10));
	isHorizontal.addItemListener(this);

	// Scrollbar for chart depth adjustment
	depth=new JScrollBar(Scrollbar.HORIZONTAL,5,1,0,60);
        depth.setPreferredSize(new Dimension(150,depth.getPreferredSize().height));
	
	depth.setEnabled(false);
	depth.addAdjustmentListener(this);
	
	topPanel.add(is3D);
	topPanel.add(isHorizontal);
	topPanel.add(new JLabel("3D depth:"));
	topPanel.add(depth);
    
        Container ct=getContentPane();
	ct.add("North",topPanel);

    }

    private void setLineSeriesProperties() {
	// Sets color
	ls1.setColor(Color.blue);
	ls2.setColor(Color.red.darker());
	
	// Line series is dashed.
	ls2.setStyle(LineSerie.DASHED);

	// Sets line thickness
	ls1.setThickness(2);

	// Sets marks color
	ls1.setMarksColor(Color.blue);
	ls2.setMarksColor(Color.magenta);
		
	// Sets data points mark style.
	ls1.setMarksStyle(LineSerie.SOLID_TRIANGLE_MARK);
	ls2.setMarksStyle(LineSerie.SOLID_SQUARE_MARK);

	// Sets legend symbol shape to match data points mark style.
	ls1.setLegendStyle(LineSerie.MARK_SHAPE_LEGEND);
	ls2.setLegendStyle(LineSerie.MARK_SHAPE_LEGEND);

	// Enables display of data points legends.
	ls1.setMarkLegendEnabled(true);

	// Sets  data point legend font.
	ls1.setFont(new Font("SansSerif",Font.PLAIN,10));
    
    }

    private void setChartProperties() {
	
	graph.setBackground(new Color(255,255,204));

	// Enables tooltip
        graph.getToolTip().setEnabled(true);

	// Sets chart title
	String[] title={"The JetChart Library - Demo","with two line series"};
	graph.setTitle(title);
	
	// Sets bottom title
	graph.getBottomTitle().setText("Labels Title");

	// Sets left title
	graph.getLeftTitle().setText("Values Title");

	// Enables chart and legend dragging. A double-click  alternates
	// between dragging chart and chart resizing.
	graph.setDraggingEnabled(true);

	// Enables grid and sets grid color
	Grid grid=graph.getGraphSet(0).getGrid();
	grid.setEnabled(true);
	grid.setColor(Color.gray.darker());

	// Sets grid style to dashed and changes dash size and space
	// between dashes.
	grid.setStyle(Grid.DASHED);
	grid.setDashSpace(2);
	grid.setDashSize(2);
	
	// Sets legend orientation.
	graph.getLegend().setOrientation(Legend.HORIZONTAL);

	// Sets scale values format.
	graph.getGraphSet(0).getScale().setValueFormat("###,###0.00");
    
	// Sets vertical chart depth.
	graph.setVDepth(5);

	// Sets horizontal chart depth.
	graph.setHDepth(5);
    }



    public static void main(String[] args) {
	new Main();
    }
}
