import com.jinsight.jetchart.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;

/**
 * This  application  demonstrates  how  to  get  pie chart  data  from  an  XML source.
 * The GenericGraph class implements the method GenericGraph.readXMLData(Reader reader),
 * which  can  be  invoked  from  subclasses  to populate  chart data. In this demo, the
 * PieGraph  class  is  instantiated to  display  a  pie  chart.  Slices  values, titles 
 * and colors  are read from the chart.xml text file. Open  this  file to get additional
 * information concerning the XML elements used to retrieve pie chart data.
 *      
 * @author - Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame {

    PieGraph graph;

    public Main() {

	setTitle("The JetChart Library - reading data from an XML file");

	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
 
	    });

	// Creates the chart context.
	graph=new PieGraph();

	// Enables tooltips.
	graph.getToolTip().setEnabled(true);

	graph.setTitle(new String[]{"The JetChart Library",
				    "Reading data from an XML file"});
	
	// Creates a pie series and enables slices borders.
	PieSerie ps=new PieSerie();
	ps.setBorderEnabled(true); 

	// Adds pie series to the chart context.
	graph.addSerie(ps);

	// Reads data from the xml file.
	readXMLData();

        Container ct=getContentPane();
	ct.add("Center",graph);

	setSize(450,350);

	setVisible(true);

	    
    }

    private void readXMLData() {

	FileReader fr=null;

	try {
	    // Opens the chart.xml file and starts reading it.
	    fr=new FileReader("chart.xml");
	    graph.readXMLData(fr);

	}
	catch (IOException e) {
	    e.printStackTrace();
	}
	finally {
	    try {
		if (fr!=null)
		    fr.close();
	    }
	    catch (IOException e) {
		e.printStackTrace();
	    }
	}
	    
    }


    public static void main(String[] args) {
	new Main();
    }

}

			  

		
