import com.jinsight.jetchart.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;
import java.util.Locale;

/**
 * This  application  demonstrates  how  to   get  labels   and   series   values   from   an    XML
 * source. The  GenericGraph  class  implements  the  method GenericGraph.readXMLData(Reader reader),
 * which   can  be  invoked   from   subclasses   to   populate  chart  labels   and  series  values.
 * In  this  demo, the  Graph class  is  instantiated   and  used  to  display two series. Labels and 
 * values   are   read   from   the  chart.xml  text file.   Open   this   file  to  get   additional 
 * information  concerning  the XML  elements  used  to retrieve labels and values. Data is read from 
 * the chart.xml every 1 second. If the   xml  file data is changed while  running  this application,
 * the chart is immediately   updated  to  reflect changes.
 *
 * @author - Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements Runnable {

    BarSerie bs1,bs2;
    
    Graph graph;

    Thread t;

    public Main() {

	setTitle("The JetChart Library - reading data from an XML file");
	setSize(450,350);

	// Creates an anonymous class to close application.
	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });
	
	// Creates the chart context.
	createChartContext();
	
	// Creates two bar series.
	createBarSeries();
	
	// Adds series to the chart context.
	graph.addSerie(bs1);
	graph.addSerie(bs2);
	
        Container ct=getContentPane();
	ct.add("Center",graph);
	
	setVisible(true);
	
	// Starts thread to read data from the xml file.
	t=new Thread(this);
	t.start();
	
    }
    
    public void run() {
	
	while (t==Thread.currentThread()) {
	    
	    try {
		
		// Reads the chart.xml file.
		readXMLData(graph);
		graph.repaint();
		Thread.sleep(1000); // Sleeps for 1 second.
		
	    }
	    catch (InterruptedException e) {
		e.printStackTrace();
	    }
	}
	
    }
    
    
    private void createChartContext() {

	// Creates the chart context.
	graph=new Graph();

	graph.setTitle(new String[]{"The JetChart Library","Reading data from an XML file"});

	// Enables grid.
	Grid grid=graph.getGraphSet(0).getGrid();
	grid.setEnabled(true);
	grid.setColor(Color.lightGray);

	// Sets grid style as DASHED.
	grid.setStyle(Grid.DASHED);

    }

    private void createBarSeries() {

	// Creates a bar series.
	bs1=new BarSerie();
	
	// The series id is set to 0. This value must match the 'id' attribute value 
	// found in the chart.xml file, added to the <series> xml element.
	bs1.setId(0);
	
	// Sets the bar series color to blue.
	bs1.setColor(Color.blue);
	
	// Sets the bar series title.
	bs1.setTitle("Blue series");

	// Creates a bar series.
	bs2=new BarSerie();
	
	// The series id is set to 1. This value must match the 'id' attribute value 
	// found in the chart.xml file, added to the <series> xml element.
	bs2.setId(1);

	// Sets the bar series title.
	bs2.setTitle("Green series");

	// Sets bar series color to green.
	bs2.setColor(Color.green.darker());

    }
	
    private void readXMLData(Graph graph) {
	
	FileReader fr=null;

	// The readXMLData method below throws an IOException, so we must enclose it
	// within a try-catch block.
	try {

	    // Opens a character stream to read the chart.xml file.
	    fr=new FileReader("chart.xml");

	    // Parses the xml file. While parsing, labels and values are assigned to 
	    // the chart context and respective series.
	    graph.readXMLData(fr);


	}
	catch (Exception e) {
	    e.printStackTrace();
	}
	finally {
	    try {
		if (fr!=null)
		    fr.close();
	    }
	    catch (IOException e) {
		e.printStackTrace();
	    }
	}

    }

	    

    public static void main(String[] args) {
	new Main();
    }

}
